package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import java.math.BigInteger;
import java.util.Enumeration;

public class RSAPrivateKeyStructure extends ASN1Encodable {
   private int version;
   private BigInteger modulus;
   private BigInteger publicExponent;
   private BigInteger privateExponent;
   private BigInteger prime1;
   private BigInteger prime2;
   private BigInteger exponent1;
   private BigInteger exponent2;
   private BigInteger coefficient;
   private ASN1Sequence otherPrimeInfos = null;

   public static RSAPrivateKeyStructure getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static RSAPrivateKeyStructure getInstance(Object obj) {
      if (obj instanceof RSAPrivateKeyStructure) {
         return (RSAPrivateKeyStructure)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new RSAPrivateKeyStructure((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public RSAPrivateKeyStructure(BigInteger modulus, BigInteger publicExponent, BigInteger privateExponent, BigInteger prime1, BigInteger prime2, BigInteger exponent1, BigInteger exponent2, BigInteger coefficient) {
      this.version = 0;
      this.modulus = modulus;
      this.publicExponent = publicExponent;
      this.privateExponent = privateExponent;
      this.prime1 = prime1;
      this.prime2 = prime2;
      this.exponent1 = exponent1;
      this.exponent2 = exponent2;
      this.coefficient = coefficient;
   }

   public RSAPrivateKeyStructure(ASN1Sequence seq) {
      BigInteger var2;
      Enumeration seq1;
      if ((var2 = ((DERInteger)(seq1 = seq.getObjects()).nextElement()).getValue()).intValue() != 0 && var2.intValue() != 1) {
         throw new IllegalArgumentException("wrong version for RSA private key");
      } else {
         this.version = var2.intValue();
         this.modulus = ((DERInteger)seq1.nextElement()).getValue();
         this.publicExponent = ((DERInteger)seq1.nextElement()).getValue();
         this.privateExponent = ((DERInteger)seq1.nextElement()).getValue();
         this.prime1 = ((DERInteger)seq1.nextElement()).getValue();
         this.prime2 = ((DERInteger)seq1.nextElement()).getValue();
         this.exponent1 = ((DERInteger)seq1.nextElement()).getValue();
         this.exponent2 = ((DERInteger)seq1.nextElement()).getValue();
         this.coefficient = ((DERInteger)seq1.nextElement()).getValue();
         if (seq1.hasMoreElements()) {
            this.otherPrimeInfos = (ASN1Sequence)seq1.nextElement();
         }

      }
   }

   public int getVersion() {
      return this.version;
   }

   public BigInteger getModulus() {
      return this.modulus;
   }

   public BigInteger getPublicExponent() {
      return this.publicExponent;
   }

   public BigInteger getPrivateExponent() {
      return this.privateExponent;
   }

   public BigInteger getPrime1() {
      return this.prime1;
   }

   public BigInteger getPrime2() {
      return this.prime2;
   }

   public BigInteger getExponent1() {
      return this.exponent1;
   }

   public BigInteger getExponent2() {
      return this.exponent2;
   }

   public BigInteger getCoefficient() {
      return this.coefficient;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var10001.<init>();
      var10001.add(new DERInteger(this.version));
      var10001.add(new DERInteger(this.getModulus()));
      var10001.add(new DERInteger(this.getPublicExponent()));
      var10001.add(new DERInteger(this.getPrivateExponent()));
      var10001.add(new DERInteger(this.getPrime1()));
      var10001.add(new DERInteger(this.getPrime2()));
      var10001.add(new DERInteger(this.getExponent1()));
      var10001.add(new DERInteger(this.getExponent2()));
      var10001.add(new DERInteger(this.getCoefficient()));
      ASN1Sequence var2;
      if ((var2 = this.otherPrimeInfos) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
